@@ -2,11 +2,13 @@
 """Loadable fixture components"""
 
 __all__ = ['SQLAlchemyFixture', 'SQLObjectFixture', 'GoogleDatastoreFixture',
-           'DjangoFixture']
+           'DjangoFixture', 'StormFixture']
 import loadable
 __doc__ = loadable.__doc__
 from loadable import *
 from sqlalchemy_loadable import SQLAlchemyFixture
 from sqlobject_loadable import SQLObjectFixture
 from google_datastore_loadable import GoogleDatastoreFixture
-from django_loadable import DjangoFixture
\ No newline at end of file
+from django_loadable import DjangoFixture
+from storm_loadable import StormFixture
+
